bayespy.inference.vmp.nodes.gaussian.GaussianGammaToGaussianWishart.__init__
============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaToGaussianWishart.__init__